'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var reshapePreactComponents = require('reshape-preact-components');
var marked = _interopDefault(require('marked'));
var Image = _interopDefault(require('@hashicorp/hashi-image'));
var Button = _interopDefault(require('@hashicorp/hashi-button'));
var assign = _interopDefault(require('object-assign'));
var preact = require('preact');

function dropdownMenu(_ref) {
  var name = _ref.name,
      enter = _ref.enter,
      exit = _ref.exit,
      lockup = _ref.lockup,
      children = _ref.children;

  return preact.h(
    'li',
    null,
    preact.h(
      'a',
      { onClick: enter },
      name,
      ' ',
      preact.h('i', { 'class': 'down' })
    ),
    preact.h(
      'div',
      { 'class': 'submenu ' + name.toLowerCase().replace(/\s/, '-') },
      preact.h(
        'ul',
        null,
        preact.h(
          'li',
          { 'class': 'close', onClick: exit },
          '\u2039 Main Menu'
        ),
        preact.h(
          'li',
          { 'class': 'name' },
          name
        ),
        children
      ),
      preact.h(
        'div',
        { 'class': 'promo' },
        preact.h(Image, {
          classes: 'bg',
          src: lockup.image.url,
          svg: lockup.image.format === 'svg',
          alt: lockup.image.alt,
          sizes: '600w'
        }),
        preact.h('h2', { dangerouslySetInnerHTML: { __html: marked(lockup.title) } }),
        preact.h('div', {
          'class': 'text',
          dangerouslySetInnerHTML: { __html: marked(lockup.body) }
        }),
        preact.h(Button, assign(lockup.cta, { theme: 'light-outline' }))
      )
    )
  );
}

function HoverSwapImg(_ref) {
  var data = _ref.data;

  return preact.h(
    "div",
    { "class": "hover-img-container" },
    preact.h("img", { "class": "black", src: data.icon.url, alt: data.icon.alt }),
    preact.h("img", { "class": "white", src: data.light_icon.url, alt: data.light_icon.alt })
  );
}

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var Nav = function (_Component) {
  _inherits(Nav, _Component);

  function Nav(props) {
    _classCallCheck(this, Nav);

    var _this = _possibleConstructorReturn(this, (Nav.__proto__ || Object.getPrototypeOf(Nav)).call(this, props));

    _this.state = { mobileMenuActive: false };
    _this.toggleMobileMenu = _this.toggleMobileMenu.bind(_this);
    _this.enterMobileSubnav = _this.enterMobileSubnav.bind(_this);
    _this.exitMobileSubnav = _this.exitMobileSubnav.bind(_this);
    return _this;
  }

  _createClass(Nav, [{
    key: 'render',
    value: function render() {
      var data = reshapePreactComponents.decode(this.props._data);
      return preact.h(
        'nav',
        { 'class': 'g-nav', 'data-state': this.props._state },
        preact.h(
          'div',
          { 'class': 'g-container' },
          preact.h(
            'div',
            { 'class': 'mobile' },
            preact.h(
              'a',
              { href: 'https://www.hashicorp.com/' },
              preact.h('img', {
                'class': 'logo',
                src: data.primary_logo.url,
                alt: data.primary_logo.alt
              })
            ),
            preact.h(
              'div',
              {
                'class': this.state.mobileMenuActive ? 'burger active' : 'burger',
                onClick: this.toggleMobileMenu
              },
              preact.h('span', null),
              preact.h('span', null),
              preact.h('span', null),
              preact.h('span', null)
            )
          ),
          preact.h('div', {
            'class': this.state.mobileMenuActive ? 'overlay active' : 'overlay'
          }),
          preact.h(
            'ul',
            { 'class': this.state.mobileMenuActive ? 'links active' : 'links' },
            preact.h(
              'li',
              { 'class': 'logo' },
              preact.h(
                'a',
                { href: 'https://www.hashicorp.com/' },
                preact.h('img', {
                  'class': 'logo',
                  src: data.primary_logo.url,
                  alt: data.primary_logo.alt
                })
              )
            ),
            preact.h(
              dropdownMenu,
              {
                name: 'Products',
                enter: this.enterMobileSubnav,
                exit: this.exitMobileSubnav,
                lockup: data.products_image_lockup
              },
              data.enterprise_products.map(function (item) {
                return preact.h(
                  'li',
                  { key: item.name, 'class': item.slug },
                  preact.h(
                    'a',
                    {
                      'data-ga-header': 'Products | ' + item.name,
                      href: 'https://www.hashicorp.com/products/' + item.slug
                    },
                    preact.h(
                      'span',
                      { 'class': 'keyword' },
                      item.subtitle
                    ),
                    preact.h(
                      'div',
                      { 'class': 'title' },
                      preact.h(HoverSwapImg, {
                        data: {
                          icon: item.logo_dark,
                          light_icon: item.logo
                        }
                      }),
                      preact.h(
                        'span',
                        null,
                        item.name.split(' ')[0]
                      )
                    )
                  )
                );
              })
            ),
            preact.h(
              dropdownMenu,
              {
                name: 'Learn',
                enter: this.enterMobileSubnav,
                exit: this.exitMobileSubnav,
                lockup: data.resources_image_lockup
              },
              data.resource_links.map(function (item) {
                return preact.h(
                  'li',
                  { key: item.title },
                  preact.h(
                    'a',
                    {
                      'data-ga-header': 'Learn | ' + item.title,
                      href: '' + item.url
                    },
                    preact.h(
                      'div',
                      { 'class': 'title' },
                      preact.h(HoverSwapImg, { data: item }),
                      item.title
                    )
                  )
                );
              })
            ),
            preact.h(
              dropdownMenu,
              {
                name: 'Company',
                enter: this.enterMobileSubnav,
                exit: this.exitMobileSubnav,
                lockup: data.company_image_lockup
              },
              data.company_links.map(function (item) {
                return preact.h(
                  'li',
                  { key: item.title },
                  preact.h(
                    'a',
                    {
                      'data-ga-header': 'Company | ' + item.title,
                      href: item.url
                    },
                    preact.h(
                      'div',
                      { 'class': 'title' },
                      preact.h(HoverSwapImg, { data: item }),
                      item.title
                    )
                  )
                );
              })
            ),
            preact.h(
              dropdownMenu,
              {
                name: 'Partners',
                enter: this.enterMobileSubnav,
                exit: this.exitMobileSubnav,
                lockup: data.partner_image_lockup
              },
              data.partner_links.map(function (item) {
                return preact.h(
                  'li',
                  { key: item.url },
                  preact.h(
                    'a',
                    {
                      href: item.url,
                      'data-ga-header': 'Partners | ' + item.title
                    },
                    preact.h(
                      'div',
                      { 'class': 'title' },
                      preact.h(HoverSwapImg, { data: item }),
                      item.title
                    )
                  )
                );
              })
            ),
            preact.h(
              dropdownMenu,
              {
                name: 'Docs',
                enter: this.enterMobileSubnav,
                exit: this.exitMobileSubnav,
                lockup: data.open_source_image_lockup
              },
              data.open_source_tools.map(function (item) {
                return preact.h(
                  'li',
                  { key: item.name },
                  preact.h(
                    'a',
                    {
                      'data-ga-header': 'Docs | ' + item.name,
                      href: item.website,
                      rel: 'noopener noreferrer',
                      target: '_blank'
                    },
                    preact.h(
                      'div',
                      { 'class': 'title' },
                      preact.h(HoverSwapImg, {
                        data: {
                          icon: item.logo,
                          light_icon: item.logo_light
                        }
                      }),
                      item.name
                    ),
                    preact.h(
                      'span',
                      { 'class': 'description' },
                      item.description
                    )
                  )
                );
              })
            ),
            data.navigation_links.map(function (item) {
              return preact.h(
                'li',
                { key: item.title, 'class': 'no-dropdown' },
                preact.h(
                  'a',
                  {
                    'data-ga-header': item.title,
                    href: item.url || '/' + item.slug
                  },
                  item.title
                )
              );
            }),
            preact.h(
              'li',
              { 'class': 'button' },
              preact.h(
                'a',
                { href: data.cta_button.url },
                data.cta_button.title,
                preact.h('i', null)
              )
            )
          )
        )
      );
    }
  }, {
    key: 'toggleMobileMenu',
    value: function toggleMobileMenu() {
      this.setState({ mobileMenuActive: !this.state.mobileMenuActive });
      document.body.classList.toggle('g-noscroll');
    }
  }, {
    key: 'enterMobileSubnav',
    value: function enterMobileSubnav(e) {
      if (window.matchMedia('(max-width: 1000px)').matches) {
        var submenu = e.currentTarget.nextElementSibling;
        submenu.classList.add('active');
      }
    }
  }, {
    key: 'exitMobileSubnav',
    value: function exitMobileSubnav() {
      var submenus = document.querySelectorAll('nav .submenu.active');
      for (var i = 0; i < submenus.length; i++) {
        submenus[i].classList.remove('active');
      }
    }
  }]);

  return Nav;
}(preact.Component);

module.exports = Nav;
